==> owncloud-8.1.0p2.tgz: owncloud/apps/updater/l10n/de_DE.js <==
OC.L10N.register(
    "updater",
    {
    "Version not found" : "Version nicht gefunden",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "Upgrade nicht möglich. Ihr Webserver hat keine Berechtigung zum Entfernen des folgenden Verzeichnisses:",
    "Update permissions on this directory and its content or remove it manually first." : "Aktualisieren Sie die Berechtigungen für dieses Verzeichnis und seinen Inhalt oder löschen Sie es vorher manuell.",
    "Unable to switch channel." : "Kanalwechsel fehlgeschlagen.",
    "Update failed." : "Update fehlgeschlagen.",
    "Fetching..." : "Abrufen…",
    "<strong>The update was unsuccessful.</strong><br />Please check logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." : "<strong>Das Update ist fehlgeschlagen.</strong><br />Bitte überprüfen Sie die Protokolle auf der Administratorenseite und melden Sie dieses Problem der <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud-Community</a>.",
    "<strong>Server error.</strong> Please check web server log file for details" : "<strong>Serverfehler.</strong> Bitte überprüfen Sie die Logdatei des Webservers auf weitere Details",
    "Retry" : "Wiederholen",
    "Here is your backup:" : "Hier ist Ihre Sicherung:",
    "Proceed" : "Fortfahren",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Alles erledigt.</strong> Klicken Sie auf den Link unten, um das Datenbank-Upgrade zu beginnen.",
    "Production" : "Produktiv",
    "Stable" : "Stabil",
    "Beta" : "Beta",
    "Daily" : "täglich",
    "Please ask your server administrator to enable PHP zip extension." : "Bitte kontaktieren Sie Ihren Server-Administrator und bitten Sie um Aktivierung der PHP-Zip-Erweiterung.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "Es ist nicht möglich, %s auf %s zu aktualisieren. Ein Downgrade oder das Überspringen einer Hauptversion werden nicht unterstützt.",
    "Make sure that your web server has read access to the following files and directories:" : "Bitte sicher stellen, dass Ihr Server Schreibzugriff auf die folgenden Dateien und Verzeichnisse hat:",
    "Make sure that your web server has write access to the following files and directories:" : "Bitte sicher stellen, dass Ihr Server Schreibzugriff auf die folgenden Dateien und Verzeichnisse hat:",
    "Updates" : "Updates",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>Es ist eine neue Version verfügbar: {{newVersion}}</strong>",
    "Updates will be available in the updater app and ownCloud admin panel within a few days of an update announcement." : "Updates werden einige Tage nach ihrer Ankündigung über die Updater-App die ownCloud-Adminoberfläche verfügbar sein.",
    "<strong>Up to date.</strong> <em>Checked on {{checkedAt}}</em>" : "<strong>Auf dem aktuellen Stand.</strong> <em>Überprüft am {{checkedAt}}</em>",
    "1. Check & Backup" : "1. Prüfen & Sichern",
    "2. Download & Extract" : "2. Herunterladen & Entpacken",
    "3. Replace" : "3. Ersetzen",
    "Update" : "Update durchführen",
    "Update channel:" : "Update-Kanal:",
    "Please note update is possible only to a version that is greater than the one currently installed. If you upgraded from a less stable channel you will be able to upgrade from a more stable channel only after the version that is greater than you installed reaches it." : "Bitte beachten Sie, dass ein Update nur auf eine höhere Version als die derzeit installierte Version möglich ist. Haben Sie von einem weniger stabilen Kanal aktualisiert, können Sie von einen stabileren Kanal nur dann aktualisieren, wenn die erreichte Version nach der Installation höher ist.",
    "Updater-Backups" : "Updater-Backups",
    "Note" : "Hinweis",
    "Here you can find backups of the core of your ownCloud <strong>(excluding your data)</strong> after starting an update to a newer version." : "Hier finden Sie Backups des Kerns Ihrer ownCloud <strong>(ohne Ihre Daten)</strong>, nachdem Sie ein Update auf eine neuere Version gestartet haben.",
    "<strong>Please always backup your data separately before updating!</strong>" : "<strong>Bitte sichern Sie Ihre Daten immer separat, bevor Sie ein Update starten!</strong>",
    "Backup directory" : "Backup-Verzeichnis",
    "No backups found." : "Keine Backups gefunden.",
    "Backup" : "Backup",
    "Done on" : "Abgeschlossen am",
    "Size" : "Größe",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "Are you sure you want to delete {{entry.title}}" : "Soll {{entry.title}} wirklich gelöscht werden?"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/updater/l10n/de_DE.js <==
OC.L10N.register(
    "updater",
    {
    "Unable to switch channel." : "Kanalwechsel fehlgeschlagen.",
    "Version not found" : "Version nicht gefunden",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "Upgrade nicht möglich. Ihr Webserver hat keine Berechtigung zum Entfernen des folgenden Verzeichnisses:",
    "Update permissions on this directory and its content or remove it manually first." : "Aktualisieren Sie die Berechtigungen für dieses Verzeichnis und seinen Inhalt oder löschen Sie es vorher manuell.",
    "Update failed." : "Update fehlgeschlagen.",
    "Fetching..." : "Abrufen…",
    "Retry" : "Wiederholen",
    "Here is your backup:" : "Hier ist Ihre Sicherung:",
    "Proceed" : "Fortfahren",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Alles erledigt.</strong> Klicken Sie auf den Link unten, um das Datenbank-Upgrade zu beginnen.",
    "Production" : "Produktiv",
    "Stable" : "Stabil",
    "Beta" : "Beta",
    "Daily" : "täglich",
    "Please ask your server administrator to enable PHP zip extension." : "Bitte kontaktieren Sie Ihren Server-Administrator und bitten Sie um Aktivierung der PHP-Zip-Erweiterung.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "Es ist nicht möglich, %s auf %s zu aktualisieren. Ein Downgrade oder das Überspringen einer Hauptversion werden nicht unterstützt.",
    "Make sure that your web server has read access to the following files and directories:" : "Bitte sicher stellen, dass Ihr Server Schreibzugriff auf die folgenden Dateien und Verzeichnisse hat:",
    "Make sure that your web server has write access to the following files and directories:" : "Bitte sicher stellen, dass Ihr Server Schreibzugriff auf die folgenden Dateien und Verzeichnisse hat:",
    "Updates" : "Updates",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>Es ist eine neue Version verfügbar: {{newVersion}}</strong>",
    "1. Check & Backup" : "1. Prüfen & Sichern",
    "2. Download & Extract" : "2. Herunterladen & Entpacken",
    "3. Replace" : "3. Ersetzen",
    "Update" : "Update durchführen",
    "Update channel:" : "Update-Kanal:",
    "Updater-Backups" : "Updater-Backups",
    "No backups found." : "Keine Backups gefunden.",
    "Backup" : "Backup",
    "Done on" : "Abgeschlossen am",
    "Size" : "Größe",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "Are you sure you want to delete {{entry.title}}" : "Soll {{entry.title}} wirklich gelöscht werden?",
    "Backup directory" : "Backup-Verzeichnis"
},
"nplurals=2; plural=(n != 1);");
